@@ -1,7 +1,7 @@
 from preseem.grpc_client import PreseemGrpcClient
 
 from preseem.grpc_nm_model import NetworkMetadataClient, PreseemNetworkMetadataModel
-from preseem.grpc_nm_model import NetworkMetadataEntity, NetworkMetadataReference, NetworkMetadataIndex
+from preseem.grpc_nm_model import NetworkMetadataEntity, NetworkMetadataReference, NetworkMetadataIndex, NetworkMetadataLowercaseIndex
 from preseem.grpc_nm_model import Reference
 from preseem.fake_nm_model import FakeNetworkMetadataModel
 from preseem.preseem_model import PreseemModel
@@ -26,4 +26,4 @@ from preseem.network_poller_grpc import NetworkPollerGrpcClient, FakeNetworkPoll
 from preseem.load_balancer_manager_grpc import LoadBalancerManagerClient
 
 from preseem.ssl_probe import ssl_probe
-__version__ = "2.51.1"
+__version__ = "2.51.2"
