@@ -17,8 +17,10 @@ class FakeNetworkMetadataModel(object):
         self.refs_last_updated = {}
         self.pt4 = pytricia.PyTricia(32)
         self._index = {x.type: {} for x in indexes or []}
+        self._index_cfg = {x.type: {} for x in indexes or []}
         for index in indexes or []:
             self._index[index.type][index.attribute] = {}
+            self._index_cfg[index.type][index.attribute] = {}
 
     def close(self):
         pass
@@ -76,6 +78,8 @@ class FakeNetworkMetadataModel(object):
             index = self._index.get(ref.type)
             if index is not None:
                 for ia, ir in index.items():
+                    is_lower = isinstance(self._index_cfg[ref.type][ia],
+                                          NetworkMetadataLowercaseIndex)
                     if ia == '_LOWER':
                         refs = ir.get(None)
                         if refs is None:
@@ -86,11 +90,15 @@ class FakeNetworkMetadataModel(object):
                         # Remove the old ref from any indexes
                         attr = cur.attributes.get(ia)
                         if attr:
+                            if is_lower:
+                                attr = attr.lower()
                             refs = ir.get(attr)
                             if refs:
                                 refs.pop(ref.value, None)
                     attr = ref.attributes.get(ia)
                     if attr:
+                        if is_lower:
+                            attr = attr.lower()
                         refs = ir.get(attr)
                         if refs is None:
                             refs = ir[attr] = {}
@@ -111,6 +119,8 @@ class FakeNetworkMetadataModel(object):
                 index = self._index.get(ref.type)
                 if index is not None:
                     for ia, ir in index.items():
+                        is_lower = isinstance(self._index_cfg[ref.type][ia],
+                                              NetworkMetadataLowercaseIndex)
                         if ia == '_LOWER':
                             refs = ir.get(None)
                             if refs:
@@ -118,6 +128,8 @@ class FakeNetworkMetadataModel(object):
                             continue
                         attr = ref.attributes.get(ia)
                         if attr:
+                            if is_lower:
+                                attr = attr.lower()
                             refs = ir.get(attr)
                             if refs:
                                 refs.pop(ref.value, None)
