@@ -246,7 +246,8 @@ class PreseemGrpcClient(object):
                                   grpc.StatusCode.UNKNOWN,
                                   grpc.StatusCode.UNIMPLEMENTED,
                                   grpc.StatusCode.INVALID_ARGUMENT,
-                                  grpc.StatusCode.PERMISSION_DENIED):
+                                  grpc.StatusCode.PERMISSION_DENIED,
+                                  grpc.StatusCode.RESOURCE_EXHAUSTED):
                     raise
                 if retry_num == num_retries:
                     logging.warning('Error calling service: %s (%s)', err.code(),
