@@ -1,7 +1,7 @@
 """Data structures used to manipulate the model locally within a data source."""
 from .util import normalize_mac
 from collections import namedtuple
-from ipaddress import ip_network
+from ipaddress import ip_address, ip_network
 from preseem_protobuf.model import service_pb2
 
 
@@ -396,3 +396,89 @@ class Service(Errorable):
 
     def __hash__(self):
         return hash(self.id)
+
+
+class Router(Errorable):
+    """Router class to use within a data source."""
+    __slots__ = ["_id", "_host", "_name", "_site", "_url"]
+
+    def __init__(self, id, **kwargs):
+        super().__init__()
+        if id is None or str(id) == '':
+            raise ValueError("The 'id' parameter for a Router must be non-empty.")
+        self._id = str(id)
+        self._host = None
+        self._name = None
+        self._site = None
+        self._url = None
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def id(self):
+        return self._id
+
+    @property
+    def host(self):
+        return self._host
+
+    @host.setter
+    def host(self, value):
+        if value is not None:
+            try:
+                ip = ip_address(value)
+            except (TypeError, ValueError) as err:
+                self.err('host', value, err)
+                return None
+        self._host = str(ip) if value is not None else None
+
+    @property
+    def name(self):
+        return self._name
+
+    @name.setter
+    def name(self, value):
+        if value is not None:
+            if not isinstance(value, str):
+                self.err(
+                    'name', value,
+                    TypeError("The router 'name' parameter must be of type string."))
+                return
+            if value == "":
+                self.err('name', value,
+                         "The router 'name' parameter must be non-empty.")
+                return
+        self._name = str(value) if value is not None else None
+
+    @property
+    def site(self):
+        return self._site
+
+    @site.setter
+    def site(self, value):
+        if value is not None:
+            if not isinstance(value, str):
+                self.err(
+                    'site', value,
+                    TypeError("The router 'site' parameter must be of type string."))
+                return
+            if value == "":
+                self.err('site', value,
+                         "The router 'site' parameter must be non-empty.")
+                return
+        self._site = str(value) if value is not None else None
+
+    @property
+    def url(self):
+        return self._url
+
+    @url.setter
+    def url(self, value):
+        if value is not None:
+            if not isinstance(value, str):
+                self.err('url', value, "The router 'url' parameter must be a string.")
+                return
+            if value == "":
+                self.err('url', value, "The router 'url' parameter must be non-empty.")
+                return
+        self._url = value if value is not None else None
