@@ -3,7 +3,7 @@ import unittest
 from hashlib import sha256
 from uuid import uuid4
 
-from preseem.source_model import Attachment, Service
+from preseem.source_model import Attachment, Router, Service
 
 class TestSourceModel(unittest.TestCase):
     def setUp(self):
@@ -22,6 +22,85 @@ class TestSourceModel(unittest.TestCase):
         self.assertEqual(err.value, value)
         
 
+    def test_router_id(self):
+        """Test field checking of router.id"""
+        with self.assertRaises(TypeError):
+            Router()  # id is required
+        with self.assertRaises(ValueError):
+            Router(None)  # id can't be None
+        with self.assertRaises(ValueError):
+            Router("")  # id can't be empty string
+        router = Router(123)
+        self.assertEqual(router.id, "123")  # int converted to string
+        router = Router(0)
+        self.assertEqual(router.id, "0")  # int converted to string
+        router = Router("my_id")
+        with self.assertRaises(AttributeError):
+            router.id = "new_id"  # id is immutable once set
+
+    def test_router_host(self):
+        """Test field checking of router.host"""
+        router = Router("r1", host=None)
+        self.assertEqual(router.host, None)
+        router = Router("r1", host="")
+        self.assertError(router, 'host', '')  # host can't be empty
+        self.assertError(Router("R1", host=""), 'host', '')
+        router.host = "192.0.2.1"
+        self.assertEqual(router.host, "192.0.2.1")
+        router.host = "192.0.2.X"
+        self.assertError(router, 'host', '192.0.2.X') # invalid IP is checked
+        router.host = "192.0.2.1/24"
+        self.assertError(router, 'host', '192.0.2.1/24') # host can't be a subnet
+        router.host = 3221225986
+        self.assertEqual(router.host, "192.0.2.2")  # host is normalized
+        router.host = None
+        self.assertEqual(router.host, None)
+
+    def test_router_name(self):
+        router = Router("r1", name=None)
+        self.assertEqual(router.name, None)
+        router = Router("r1", name="")
+        self.assertError(router, 'name', '')  # name can't be empty
+        router = Router("r1", name='router 1')
+        self.assertEqual(router.name, 'router 1')
+        router.name = 123
+        self.assertError(router, 'name', 123)  # name must be a string
+        self.assertEqual(router.name, 'router 1')
+        router.name = 'router 2'
+        self.assertEqual(router.name, 'router 2')
+        router.name = None
+        self.assertEqual(router.name, None)
+
+    def test_router_site(self):
+        router = Router("r1", site=None)
+        self.assertEqual(router.site, None)
+        router = Router("r1", site="")
+        self.assertError(router, 'site', '')  # site can't be empty
+        router = Router("r1", site='site 1')
+        self.assertEqual(router.site, 'site 1')
+        router.site = 123
+        self.assertError(router, 'site', 123)  # site must be a string
+        self.assertEqual(router.site, 'site 1')
+        router.site = 'site 2'
+        self.assertEqual(router.site, 'site 2')
+        router.site = None
+        self.assertEqual(router.site, None)
+
+    def test_router_url(self):
+        router = Router("r1", url=None)
+        self.assertEqual(router.url, None)
+        router = Router("r1", url="")
+        self.assertError(router, 'url', '')  # url can't be empty
+        router = Router("r1", url='https://router.url')
+        self.assertEqual(router.url, 'https://router.url')
+        router.url = 123
+        self.assertError(router, 'url', 123)  # url must be a string
+        self.assertEqual(router.url, 'https://router.url')
+        router.url = 'https://router.url/routers/2'
+        self.assertEqual(router.url, 'https://router.url/routers/2')
+        router.url = None
+        self.assertEqual(router.url, None)
+
     def test_service_id(self):
         """Test field checking of service.id"""
         with self.assertRaises(TypeError):
